/*
 * This file is part of Easy Answer.
 *
 * Copyright (C) 2012 Digia Plc
 *
 * Easy Answer is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * Easy Answer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Easy Answer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.0

import "UIConstants.js" as UI

Dialog {
    id: aboutDialog
    height: parent.height
    width: parent.width

    title: Item {
        height: titleColumn.height + 16
        width: parent.width

        Column {
            id: titleColumn
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            anchors.margins: UI.DEFAULT_MARGIN
            spacing: 5

            Image {
                id: logo
                anchors.horizontalCenter: parent.horizontalCenter
                source: "easyanswer.png"
            }

            Label {
                id: title
                anchors.horizontalCenter: parent.horizontalCenter
                style: LabelStyle { inverted: true }
                font.pixelSize: 48
                font.bold: true
                text: "Easy Answer"
            }

            Label {
                id: version
                anchors.horizontalCenter: parent.horizontalCenter
                style: LabelStyle { inverted: true }
                text: "Version 1.1.0"
            }
        }

        MouseArea {
            anchors.fill: parent
            z: -1
        }
    }

    content: Item {
        height: contentColumn.height + 16
        width: parent.width
        anchors.topMargin: 10

        Column {
            id: contentColumn
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            anchors.margins: UI.DEFAULT_MARGIN
            width: aboutDialog.width
            spacing: 16

            Label {
                font.pixelSize: 22
                anchors.left: parent.left
                anchors.right: parent.right
                style: LabelStyle { inverted: true }
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                text: "Easy Answer lets you answer and end a call by using different gestures. This can come in handy when it's tricky to press the touch screen buttons for some reason."
            }

            Item {
                height: 16
                width: parent.width
            }

            Label {
                id: copyright
                font.pixelSize: 22
                anchors.left: parent.left
                anchors.right: parent.right
                style: LabelStyle { inverted: true }
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                textFormat: Text.RichText
                text: "<style>a{color:#FFFFFF}</style>Licensed under GNU LGPL version 2.1<br>Source code available on Gitorius<br><a href=\"https://gitorious.org/easyanswer\">https://gitorious.org/easyanswer</a><br>Copyright © 2012  Digia Plc"
                onLinkActivated: {
                    Qt.openUrlExternally(link);
                }
            }

            Item {
                height: 2
                width: parent.width
            }

            Image {
                id: digiaLogo
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.margins: 10
                source: "Digia.png"
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        Qt.openUrlExternally("http://www.digia.com/")
                    }
                }
            }

            Label {
                id: digiaLink
                anchors.horizontalCenter: parent.horizontalCenter
                style: LabelStyle { inverted: true }
                textFormat: Text.RichText
                text: "<style>a{color:#FFFFFF}</style><a href=\"http://www.digia.com/\">www.digia.com</a>"
                onLinkActivated: {
                    Qt.openUrlExternally(link);
                }
            }
        }

        MouseArea {
            anchors.fill: parent
            z: -1
        }
    }

    buttons: Item {
        height: okButton.height + 64
        width: parent.width

        Button {
            id: okButton
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            style: ButtonStyle { inverted: true }
            __dialogButton: true
            text: "OK"
            onClicked: {
                aboutDialog.close();
            }
        }

        MouseArea {
            anchors.fill: parent
            z: -1
        }
    }
}
