/*
 * This file is part of Easy Answer.
 *
 * Copyright (C) 2012 Digia Plc
 *
 * Easy Answer is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * Easy Answer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Easy Answer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.0

import "UIConstants.js" as UI

Item {
    id: checkableItem
    height: titleLabel.height + descriptionLabel.height
    width: parent.width

    property string title
    property string description
    property bool enabled
    property bool checked

    signal clicked()

    CheckBox {
        id: checkBox
        anchors.verticalCenter: parent.verticalCenter
        anchors.left: parent.left
        enabled: checkableItem.enabled
        checked: checkableItem.checked
        platformStyle: CheckBoxStyle {
            backgroundDisabled: checkBox.checked ? "image://theme/color2-meegotouch-button-checkbox"+__invertedString+"-background-selected-disabled" : "image://theme/meegotouch-button-checkbox"+__invertedString+"-background-disabled"
        }
    }

    Label {
        id: titleLabel
        anchors.top: parent.top
        anchors.left: checkBox.right
        anchors.right: parent.right
        color: checkableItem.enabled ? UI.ENABLED_FONT_COLOR : UI.DISABLED_FONT_COLOR
        text: checkableItem.title
    }

    Label {
        id: descriptionLabel
        anchors.bottom: parent.bottom
        anchors.left: checkBox.right
        anchors.right: parent.right
        color: UI.DISABLED_FONT_COLOR
        wrapMode: Text.WordWrap
        text: checkableItem.description
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            checkBox.checked = !checkBox.checked;
            checkableItem.checked = checkBox.checked;
            checkableItem.clicked();
        }
    }
}
